@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 # shortcuts
 #  os and distros
@@ -197,6 +197,8 @@ sub mapping {
        [package => 'libcfitsio-dev']],
       [like_fedora,
        [package => 'cfitsio-devel']], # but test fails on CentOS7 (undefined symbol: ffgsky)
+      [os_darwin,
+       [package => 'homebrew/science/cfitsio']],
      ],
 
      [cpanmod => 'Astro::WCS::LibWCS',
@@ -416,8 +418,9 @@ sub mapping {
      ],
 
      [cpanmod => 'Compress::LZMA::Simple',
-      [os_freebsd,
-       [package => 'lzmalib']],
+      ## in the meanwhile, lzma is part of the base install
+      #[os_freebsd,
+      # [package => 'lzmalib']],
      ],
       
      [cpanmod => 'Compress::Raw::Lzma',
@@ -945,7 +948,10 @@ sub mapping {
       [os_freebsd,
        [package => 'gobject-introspection']],
       [like_debian,
-       [package => 'libgirepository1.0-dev']]],
+       [package => 'libgirepository1.0-dev']],
+      [os_darwin,
+       [package => [qw(gobject-introspection libffi)]]],
+     ],
 
      [cpanmod => 'Gnome2',
       [os_freebsd,
@@ -1893,7 +1899,10 @@ sub mapping {
       [os_freebsd,
        [package => ['poppler', 'poppler-glib']]],
       [like_debian,
-       [package => ['libpoppler-dev', 'libpoppler-glib-dev']]]],
+       [package => ['libpoppler-dev', 'libpoppler-glib-dev']]],
+      [os_darwin,
+       [package => 'poppler']],
+     ],
 
      [cpanmod => 'Prima',
       # XXX what about freebsd?
